const app = getApp()
const wxService = require('../../../utils/wxService')
const util = require('../../../utils/util')
const envInfo = require('../../../config/index').envInfo

wxService.page({
    data: {
        goodList: [], // 商品列表
        chooseList: [], // 选中的商品
        custNo: null, // 用户编号
        shoppingCartId: null, // 购物车id
        colorUrl1: '../images/choose-good.png', // 列表未选择
        colorUrl2: '../images/choosen-good.png', // 选中
        iconId: -1, // 总计选中标识
        editFlag: false, // 编辑标识
        totalPrice: 0, // 总价
        toFlag: false, // 是否选择商品
        pageNo: null,
        payOrderConfig: {},
        // storeName: null,
        isGoods: true,


        outGoods: [],  //失效商品
        outGoodIds: [],   //失效商品ids
        checkAll: true,
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        wx.showLoading({
            title: '加载中'
        })

        this.getCarList()
    },


    getCarList(){
        let cartList = wx.getStorageSync('_cartList');
        let totalPrice = 0;
        cartList = cartList ? cartList.map(item => {
            item.count = item.count ? item.count : 1;
            totalPrice = totalPrice + (item.price * item.count * 1000) / 1000
            item.isChoose = true;
            return item;
        }) : [];
        this.setData({
            goodList: cartList,
            totalPrice: parseFloat(totalPrice).toFixed(2)
        })
    },
    
    // 选择商品
    chooseGood: function (e) {
        var checkAll = false
        let _scope = this

        let id = e.currentTarget.dataset.id;
        let num = e.currentTarget.dataset.num;
        let data = _scope.data.goodList;
        let list = _scope.data.chooseList

        if (num != 0) {
            data[id].isChoose = !data[id].isChoose
            _scope.setData({
                goodList: data,
                iconId: id
            })
            list = data.filter(item => {
                return item.isChoose
            }).map(item => {
                return {
                    ...item,
                    storeName: this.data.storeName
                }
            })
            //  所有单个选中 ，全选
            if (data.filter(function (item) {
                if (item.stockNum != 0) {
                    return item
                }
            }).length === data.filter(function (item) {
                return item.isChoose
            }).length) {
                checkAll = true
            } else {
                checkAll = false
            }
            _scope.setData({
                chooseList: list,
                checkAll: checkAll
            })
            _scope.setTotalPrice()
        } else {
            util.alert('该商品没有库存哦~')
        }
    },
    // 删除商品
    cancelGood: function (e) {
        let index = e.currentTarget.dataset.id;
        let list = this.data.goodList;
        list.splice(index, 1);
        wx.setStorageSync('_cartList', list);
        this.setTotalPrice();
        this.setData({
            goodList: list
        })
        wx.showToast({
            title: '删除商品成功',
            icon: 'none'
        })
    },

    // 验证是否满足下单设置
    validateOrder(storeLimitNum, { inventoryLimitQuantity, inventoryLimitFlag }) {
        let pass = false
        if (inventoryLimitFlag && (inventoryLimitQuantity - storeLimitNum > 0)) {
            pass = true
        } else if (!inventoryLimitFlag) {
            pass = true
        }
        return pass
    },
    // 跳转提交页
    toDetail: function () {
        let _scope = this
        if (_scope.data.isGoods) {
            let goodArr = _scope.data.goodList
            let choose = goodArr.filter(item => item.isChoose)
            if (choose && choose.length) {
                _scope.setData({
                    toFlag: true
                })
            }

            if (choose.length == 0) {
                util.alert('您还没有选择商品哦~')
                return false
            }

            const storeInventoryQuantity = choose && choose[0].storeInventoryQuantity || 0
            const chooseFilter = choose.filter((item) => {
                return this.validateOrder(storeInventoryQuantity, this.data.payOrderConfig)
            })
            if (chooseFilter.length === 0) {
                wx.showToast({
                    title: '您选择的商品门店中都有存库,您可以直接在门店进行购买。',
                    icon: 'none'
                })
                return false
            }
            if (choose.length > 0) {
                let goodsList = choose.map(item => {
                    return {
                        skuCode: item.barCode,
                        quantity: item.count
                    }
                })

                let goodsInfo = {
                    goodsList: goodsList,
                    storeId: wx.getStorageSync('_storeId')
                };
                wx.setStorageSync('goodsInfo',goodsInfo);
        
                wx.navigateTo({
                    url : '/omniChannel/pages/submitOrder/submitOrder?from=cart'
                });
            } else {
                util.alert('您还没有选择商品哦~')
            }
        }
    },

    setTotalPrice(){
        let that = this;
        let totalPrice = 0;
        this.data.goodList.map((item) => {
            if (item.stockNum && item.isChoose) {
                totalPrice = totalPrice + (item.price * item.count * 1000) / 1000
            }
        })

        that.setData({
            totalPrice: parseFloat(totalPrice).toFixed(2)
        })
    },

    //清空失效商品
    clearOutTimeGoods() {
        let ids = this.data.outGoodIds.join(',')
        let token = wx.getStorageSync('token')
        let that = this

        wxService.get('shopCart/deleteShopCartInfoByIds', {
            ids,
            token: token
        }).then(res => {
            if (res.data.code === 200) {
                wx.showToast({
                    title: '失效商品已清除',
                    icon: 'none'
                })
            }
            that.setData({
                outGoods: [],
                outGoodIds: []
            })
        })
    },
    // 全选
    checkAll: function () {
        let that = this
        var goodList = this.data.goodList || []
        if (!goodList.length) return false
        
        if (this.data.checkAll) {
            this.setData({
                goodList: goodList.map(function (item) {
                    item.isChoose = false
                    return item
                }),
                checkAll: false
            }, () => {
                that.setTotalPrice()
            })
        } else {
            this.setData({
                goodList: goodList.map(function (item) {
                    // 区分失效商品
                    if (item.stockNum != 0) {
                        item.isChoose = true
                        return item
                    } else {
                        item.isChoose = false
                        return item
                    }
                }),
                checkAll: true,
            }, () => {
                that.setTotalPrice()
            })
        }

    },
})
