// 获取应用实例
const app = getApp()

const util = require('../../../utils/util.js')
const envInfo = require('../../../config/index').envInfo
const wxService = require('../../../utils/wxService')
const pageParmas = require('../../../utils/common').parmas

wxService.page({
    data: {
        goodsTotalPrice: 0, // 商品总价
        stock: false, // 蒙层标识
        isCoupon: false, // 优惠券标识
        couponLen: 0, // 优惠券数量
        couponArr: [], // 跳转优惠券列表对象
        couponObj: null, // 优惠券页面传过来的数据
        couponPrice: 0, // 优惠金额
        goodInfo: [], // 商品信息
        totalPrice: 0, // 总价
        logisticsTotalFee: -1, // 运费
        promotionInfo: {
            totalPrice: 0,
            price: 0
        },
        promotionName: '', // 促销名称
        isCart: 0,
        custNo: null,
        storeId: null,
        param: {}, // 优惠券传参
        promotList: null, // 促销返回结果
        storeName: null, // 店名
        addressCode: '',
        payOrderConfig: {}, // 下单配置
        loadF: false,

        addressId: null, // 选中的地址id
        addressInfo: null, // 地址信息
        address: null, // 选中的地址
        postageData: null, // 运费
        showBadge: false, // 显示官方正品等信息
        selectedCoupon: '', //选中的优惠券
    },

    //加载
    onLoad(options) {

    },

    //生命周期onshow
    onShow() {
        this.pageInit();
    },

    //选择地址
    selectAddress() {
        wxService.router('/pages/myAddress/myAddress?isFrom=order');
    },

    //渲染本地数据
    pageInit() {
        //获取本地选择的收货地址
        this.getUserDefaultAddress();
        //获取本地商品信息
        this.getLocalGoodsInfo();

        //orderInit
        this.orderPreview();

    },

    //获取用户地址
    getUserDefaultAddress() {
        const { memberId } = wx.getStorageSync('_baseUserInfo');
        wxService.post(`/member/addressManage/getall`, { userId: memberId }).then(res => {
            if (!res) return false;
            //获取已经选择的地址
            let hasDefalut = wx.getStorageSync('_defalutAddress');
            //查找出来默认地址
            let { result, data } = res.data;
            if (result != 0) return;
            let defaultInAddressList = null;
            data = data ? data : [];
            if (!hasDefalut) {
                data.forEach(item => {
                    item.fullArea = item.province + ' ' + item.city + ' ' + item.district
                    if (item.type == 1) {
                        defaultInAddressList = item
                    }
                });
            }
            else {
                //判断地址列表中是不是已经把这个地址删除了
                let id = hasDefalut.id;
                let filterArr = data.filter(item => item.id == id);
                if (filterArr.length > 0) {
                    defaultInAddressList = hasDefalut
                } else { // 无
                    //此时已经没有 看看是不是有默认地址 有则默认选中
                    data = data ? data : [];
                    data.forEach(item => {
                        item.fullArea = item.province + ' ' + item.city + ' ' + item.district
                        if (item.type == 1) {
                            defaultInAddressList = item
                        }
                    });
                }
            }


            if (defaultInAddressList) {
                this.data.addressId = defaultInAddressList ? defaultInAddressList.id : '';
                this.data.addressInfo = defaultInAddressList;
            }

            this.setData({
                addressInfo: this.data.addressInfo,
                addressId: this.data.addressId,
            });
        });
    },

    //获取用户优惠券列表
    getUserCouponList(param) {
        wxService.post('/hotwind-express/i-offline-order/cust/coupon/list', param).then(data => {
            let res = data.data.data;
            let totalPrice = this.calcTotalPrice()
            this.setData({
                couponLen: res ? res.length : 0,
                couponArr: res ? res : [],
                totalPrice
            })
            pageParmas.setObject('_coupons', res)
        });
    },

    //订单预览
    orderPreview() {
        let storeId = this.getLocalGoodsInfo().storeId;
        const addressInfo = this.data.addressInfo
        wxService.post(`/hotwind-express/i-offline-order/init`, this.getLocalGoodsInfo()).then(data => {
            let res = data.data.data;
            let goodsTotalPrice = 0
            let promotionInfo = this.data.promotionInfo
            let stock = this.data.stock
            goodsTotalPrice = res.offlineGoodsList.reduce((total, item) => {
                return total + item.quantity * 1000 * item.price
            }, 0)
            if (res.offlineOrderPromotion) {
                promotionInfo.totalPrice = res.offlineOrderPromotion.totalPrice
                promotionInfo.price = parseFloat(goodsTotalPrice / 1000 - promotionInfo.totalPrice).toFixed(2)
            }
            const paramsFilter = res.offlineGoodsList.filter(item => {
                return !item.stockNum || item.quantity > item.stockNum
            })
            if (paramsFilter.length) {
                stock = true
            }

            ///订单商品信息
            let goddsList = res.offlineGoodsList.map(item => {
                return {
                    barCode: item.barCode,
                    price: item.price,
                    count: item.quantity
                }
            });

            this.getUserCouponList({
                storeId,
                promotionInfo: { totalPrice: promotionInfo.totalPrice },
                orderList: goddsList,
            });

            let promotionName = res.offlineOrderPromotion && res.offlineOrderPromotion.list ? res.offlineOrderPromotion.list[0].activityName : '' // 促销名称 默认取list第一个

            this.setData({
                storeId,
                stock,
                promotionInfo,
                promotionName,
                goodInfo: res.offlineGoodsList.map(item => {
                    return {
                        ...item,
                        count: item.quantity
                    }
                }),
                goodsTotalPrice: parseFloat(goodsTotalPrice / 10).toFixed()
            })

            if (addressInfo) {
                this.setLogisticsTotalFee(addressInfo)
            } else {
                let totalPrice = this.calcTotalPrice()
                this.setData({
                    totalPrice: totalPrice
                })
            }
        })
    },


    //获取购买商品数据
    getLocalGoodsInfo() {
        let goodsInfo = wx.getStorageSync('goodsInfo') ? wx.getStorageSync('goodsInfo') : null;
        if (!goodsInfo) {
            wx.showToast({
                title: '请选择商品之后进入此页面',
                icon: 'none'
            });
            return;
        }
        return goodsInfo;
    },

    //选择优惠券之后回调
    showCouponDetail(e) {
        const { id, index, name, type, obj } = e.detail
        if (e.detail && name) {
            this.setData({
                selectedCoupon: name,
                promotionInfo: { 'price': obj.price },
                couponObj: obj
            })

            this.getPromtionInfo(obj)
        }
    },

    //选择优惠券
    showCoupon(e) {
        var tempCouponArr = []
        if (this.data.couponArr && this.data.couponArr.length > 0) {
            for (var i = 0; i < this.data.couponArr.length; i++) {
                var c = this.data.couponArr[i]
                var couponObj = {}
                couponObj.id = c.couponId
                couponObj.index = i
                couponObj.name = c.couponName
                couponObj.startTime = c.beginTime
                couponObj.endTime = c.endTime
                couponObj.choose = true
                if (c.inUseFlag == '未使用') {
                    couponObj.useFlag = true
                } else {
                    couponObj.useFlag = false
                }

                couponObj.CouponUseType = c.couponUseType
                couponObj.promotionType = 2   //现金
                couponObj.displayFlag = false
                couponObj.obj = c

                if (c.couponType == 2) {//现金
                    couponObj.price = c.couponAmt
                }

                tempCouponArr.push(couponObj)
            }
        }

        this.setData({
            showCouponPopup: true,
            showCouponTip: false,
            showCouponTitle: '选择优惠券',
            couponDatas: tempCouponArr
        })
    },

    //关闭弹出框
    closeMask() {
        this.setData({
            stock: !this.data.stock
        })
        wx.navigateBack({
            delta: 1
        })
    },

    //提交订单
    toPay(event) {
        const formId = event.detail.formId
        if (!this.data.addressInfo) {
            wx.showToast({
                title: '您还没有填写收货地址哦',
                icon: 'none'
            });
            return false;
        }

        if (this.data.addressInfo.id) {
            // if (_scope.data.addressInfo) {
            let coupon = this.data.couponObj
            if (coupon && coupon.couponType == 1) { // 折扣券
                coupon.couponAmt = this.data.couponPrice
            }
            const logisticsTotalFee = 0
            this.submitOrder(formId)
        } else {
            wx.showToast({
                title: '您还没有填写收货地址哦',
                icon: 'none'
            });
            return false;
        }
    },

    //计算促销价格
    calcPromitonPrice() {
        let price = this.data.promotionInfo.totalPrice || 0
        return price * 100
    },

    //计算优惠券价格
    calcCouponPrice() {
        let price = this.data.couponPrice
        return price * 100
    },
    //计算邮费价格
    calcLogisticsPrice() {
        let price = this.data.logisticsTotalFee
        price = price > 0 ? price * 1 : 0
        return price * 100
    },

    //计算总价
    calcTotalPrice() {
        let couponPrice = this.calcCouponPrice()
        let promtionPrice = this.calcPromitonPrice()
        let logisticsPrice = this.calcLogisticsPrice()
        let goodsTotalPrice = this.data.goodsTotalPrice * 1
        let price = 0
        price = (promtionPrice || goodsTotalPrice) * 1
        price = parseFloat((price + logisticsPrice - couponPrice)).toFixed()
        return price > 0 ? price : 0 // 以分为单位
    },

    //提交订单
    submitOrder(formId) {
        let addressCode = this.data.addressInfo.districtId
        let storeId = this.data.storeId
        let addressId = this.data.addressInfo.id
        let isCart = this.data.isCart
        if (!addressId) {
            wx.showToast({
                title: '您还没有填写收货地址哦',
                icon: 'none'
            });
            return false
        }
        let totalPayPrice = this.calcTotalPrice()
        let goodsList = this.data.goodInfo.map(item => {
            return {
                skuCode: item.barCode,
                quantity: item.quantity,
                goodsImgUrl: item.listImgUrlList[0] ? item.listImgUrlList[0] : 'https://hwimagecdn.ihotwind.cn/hotwind-mini/images/kuaididaojia/kuaidaojia_default_goods_small.png'
            }
        })
        let chooseCoupen = []
        if (this.data.couponObj) {
            chooseCoupen.push(this.data.couponObj)
        }
        let couponList = chooseCoupen.map(item => {
            return {
                'couponId': item.couponId,
                'couponName': item.couponName,
                'couponType': item.couponType,
                'couponAmt': item.couponAmt,
                'promotionCondition': item.promotionCondition,
                'promotionItemList': item.promotionItemList,
                'promotionAction': item.promotionAction,
                'additionalPromotionFlag': item.additionalPromotionFlag,
                'sharePromotionFlag': item.sharePromotionFlag,
                'promotionConditionType': item.promotionConditionType,
                'repeatFlg': item.repeatFlg,
                'couponPromotionType': item.couponPromotionType
            }
        })
        wx.showLoading({
            title: '加载中',
            mack: true,
            icon: 'none'
        });


        // let params = {
        //     addressCode,
        //     addressId,
        //     isCart,
        //     formId,
        //     storeId,
        //     totalPayPrice,
        //     goodsList,
        //     couponList
        // };


        wxService.post('/hotwind-express/i-offline-order/save', {
            addressCode,
            addressId,
            storeId,
            totalPayPrice,
            goodsList,
            couponList
        }).then(res => {
            this.pay(res)
        });
    },
    //调起微信支付
    pay(obj) {
        if (!obj.data.data) {
            wx.hideLoading()
            wx.showToast({
                title: '支付失败',
                icon: 'none',
                mask: true
            })
            return;
        }
        let wxParams = obj.data.data.wxParams;
        let tradeId = obj.data.data.tradeId;
        let currentType = 'delivery';
        let amount = this.calcTotalPrice();

        wx.requestPayment({
            'timeStamp': wxParams.timeStamp,
            'nonceStr': wxParams.nonceStr,
            'package': wxParams.package,
            'signType': wxParams.signType,
            'paySign': wxParams.paySign,
            'success': _res => {
                wx.hideLoading()
                wx.showToast({
                    title: '支付成功',
                    icon: 'none',
                    mask: true
                })

                this.resetCartList();
                

                
                //消息订阅
                let baseUserInfo = wx.getStorageSync('_baseUserInfo');
                wxService.post(`${'/merchant/message/wxSubMsgMapping/getListByParams'}`, {
                    scenarioIds: ['ordersend', 'orderconfirm'],
                    sourceFrom: 2,
                    switchType: 3
                }).then(res => {
                    let tempArr = res.data.data ? res.data.data : [];
                    let currentType = 'delivery';
                    if (tempArr.length == 0) {
                        wx.reLaunch({
                            url: `/subPackage/page/pages/paymentStatus/paymentStatus?status=S&amount=${amount}&type=${currentType}`,
                        });
                        return;
                    }

                    let tempids = [];
                    tempArr.map(item => {
                        tempids.push(item.templateId);
                    });

                    wx.requestSubscribeMessage({
                        tmplIds: tempids,
                        success: (res) => {
                            for (let i = 0; i < tempArr.length; i++) {
                                wxService.post(`${'/merchant/message/wxSubMsgSubscride/member/subscribe'}`, {
                                    businessId: tradeId,
                                    memberId: baseUserInfo.memberId,
                                    scenarioId: tempArr[i].scenarioId,
                                    templateId: tempArr[i].templateId
                                }).then(resp => { });
                            }
                        },
                        complete: (res) => {
                            wx.reLaunch({
                                url: `/subPackage/page/pages/paymentStatus/paymentStatus?status=S&amount=${amount}&type=${currentType}`,
                            });
                        }
                    })
                }).catch(err => {
                    wx.reLaunch({
                        url: `/subPackage/page/pages/paymentStatus/paymentStatus?status=S&amount=${amount}&type=${currentType}`,
                    });
                })
            },
            'fail': _res => {
                wx.hideLoading()
                wx.showToast({
                    title: '支付失败',
                    icon: 'none',
                    mask: true
                })
                this.resetCartList();
                wx.reLaunch({
                    url: `/subPackage/page/pages/paymentStatus/paymentStatus?status=F&amount=${amount}&type=${currentType}`,
                });
            }
        })





        // wxService.get('/hotwind-express/order/wechatPay', {
        //     orderNo
        // }).then(res_ => {
        //     const payJson = JSON.parse(decodeURIComponent(res_.data.data.parameter))

        // });
    },


    resetCartList(){
        let cartList = wx.getStorageSync('_cartList');
        let goodsList = this.data.goodInfo;

        for(let i = 0; i < cartList.length; i++){
            for(let j = 0; j < goodsList.length; j++){
                if(cartList[i].barCode == goodsList[j].barCode){
                    cartList.splice(i, 1);
                }
            }
        }

        wx.setStorageSync('_cartList', cartList);
    }
})